@@ -1,6 +1,6 @@
 """Schema for serializing text selectors."""
 
-from typing import Dict, List, Optional, Sequence, Union
+from typing import Dict, Mapping, Optional, Sequence, TypedDict, Union
 
 from marshmallow import Schema, fields, pre_dump, post_load, pre_load
 
@@ -11,6 +11,15 @@ from anchorpoint.textselectors import (
 )
 
 
+class PositionSelectorDict(TypedDict, total=False):
+    """Dict representing TextPositionSelector, to be loaded with SelectorSchema."""
+
+    start: int
+    end: Optional[int]
+    include_start: bool
+    include_end: bool
+
+
 class SelectorSchema(Schema):
     r"""
     Schema for loading a :class:`~anchorpoint.textselectors.TextQuoteSelector` or
@@ -29,7 +38,7 @@ class SelectorSchema(Schema):
     suffix = fields.Str(missing=None)
 
     start = fields.Int()
-    end = fields.Int(optional=True)
+    end = fields.Int(missing=None)
     include_start = fields.Bool(missing=True, load_only=True)
     include_end = fields.Bool(missing=False, load_only=True)
 
@@ -43,30 +52,23 @@ class SelectorSchema(Schema):
             obj.end = obj.real_end
         return obj
 
-    def expand_anchor_shorthand(
-        self, data: Union[str, Dict[str, str]]
-    ) -> Dict[str, str]:
+    def expand_anchor_shorthand(self, text: str) -> Mapping[str, str]:
         """
         Convert input from shorthand format to normal selector format.
 
-
         .. code-block:: python
 
             >>> schema = SelectorSchema()
             >>> schema.expand_anchor_shorthand("eats,|shoots,|and leaves")
             {'exact': 'shoots,', 'prefix': 'eats,', 'suffix': 'and leaves'}
         """
-        if isinstance(data, str):
-            data = {"text": data}
-        text = data.get("text")
-        if text:
-            (
-                data["prefix"],
-                data["exact"],
-                data["suffix"],
-            ) = TextQuoteSelector.split_anchor_text(text)
-            del data["text"]
-        return data
+        result = {}
+        (
+            result["prefix"],
+            result["exact"],
+            result["suffix"],
+        ) = TextQuoteSelector.split_anchor_text(text)
+        return result
 
     def convert_bool_to_dict(self, data: bool) -> Dict[str, int]:
         """Interpret True as a TextPositionSelector including the whole section."""
@@ -77,13 +79,14 @@ class SelectorSchema(Schema):
 
     @pre_load
     def preprocess_data(
-        self, data: Union[str, Dict[str, Union[str, Dict, List]]], **kwargs
-    ) -> Dict[str, Union[str, List]]:
+        self, data: Union[str, bool, Mapping[str, Union[str, bool, int]]], **kwargs
+    ) -> Mapping[str, Union[str, bool, int]]:
         if isinstance(data, bool):
-            data = self.convert_bool_to_dict(data)
-        if data:
-            data = self.expand_anchor_shorthand(data)
-
+            return self.convert_bool_to_dict(data)
+        if isinstance(data, str):
+            return self.expand_anchor_shorthand(data)
+        if "text" in data.keys() and isinstance(data["text"], str):
+            return self.expand_anchor_shorthand(data["text"])
         return data
 
     @post_load
@@ -91,16 +94,16 @@ class SelectorSchema(Schema):
         self, data, **kwargs
     ) -> Optional[Union[TextPositionSelector, TextQuoteSelector]]:
         if data.get("exact") or data.get("prefix") or data.get("suffix"):
-            model = TextQuoteSelector
             for unwanted in ("start", "end", "include_start", "include_end"):
                 data.pop(unwanted, None)
-        else:
-            model = TextPositionSelector
-            if data.get("start") == data.get("end"):
-                return None
-            for unwanted in ("exact", "prefix", "suffix"):
-                data.pop(unwanted, None)
-        return model(**data)
+            return TextQuoteSelector(**data)
+
+        if data.get("start") == data.get("end"):
+            return None
+
+        for unwanted in ("exact", "prefix", "suffix"):
+            data.pop(unwanted, None)
+        return TextPositionSelector(**data)
 
 
 class TextPositionSetFactory:
@@ -109,6 +112,11 @@ class TextPositionSetFactory:
     def __init__(self, passage: str) -> None:
         self.passage = passage
 
+    def from_bool(self, selection: bool) -> TextPositionSet:
+        if selection is True:
+            return TextPositionSet(TextPositionSelector(0, len(self.passage)))
+        return TextPositionSet()
+
     def from_selection(
         self,
         selection: Union[
@@ -116,32 +124,51 @@ class TextPositionSetFactory:
             str,
             TextPositionSelector,
             TextQuoteSelector,
-            Sequence[TextQuoteSelector],
+            Sequence[Union[str, TextQuoteSelector, TextPositionSelector]],
         ],
     ) -> TextPositionSet:
         """Construct TextPositionSet for a provided text passage, from any type of selector."""
-        if selection is True:
-            return TextPositionSet(TextPositionSelector(0, len(self.passage)))
-        elif selection is False:
-            return TextPositionSet()
         if isinstance(selection, str):
             schema = SelectorSchema()
-            selection = schema.load(selection)
+            data = schema.expand_anchor_shorthand(selection)
+            selection = schema.load(data)
         if isinstance(selection, TextQuoteSelector):
             selection = [selection]
         elif isinstance(selection, TextPositionSelector):
-            selection = TextPositionSet(selection)
-        if isinstance(selection, Sequence):
-            if all(isinstance(item, str) for item in selection):
-                selection = [TextQuoteSelector(exact=item) for item in selection]
-            if all(isinstance(item, TextQuoteSelector) for item in selection):
-                selection = self.from_quote_selectors(quotes=selection)
-        if not isinstance(selection, TextPositionSet):
-            selection = TextPositionSet(selection)
-        return selection
+            return TextPositionSet(selection)
+        if isinstance(selection, bool):
+            return self.from_bool(selection)
+        return self.from_selection_sequence(selection)
+
+    def from_selection_sequence(
+        self, selections: Sequence[Union[str, TextQuoteSelector, TextPositionSelector]]
+    ) -> TextPositionSet:
+        """
+        Construct TextPositionSet from one or more of: strings, Quote Selectors, and Position Selectors.
+
+        First converts strings to TextQuoteSelectors, and then to TextPositionSelectors.
+        """
+        positions = []
+        for selection in selections:
+            if isinstance(selection, str):
+                selection = TextQuoteSelector(exact=selection)
+            if isinstance(selection, TextQuoteSelector):
+                selection = selection.as_position(self.passage)
+            positions.append(selection)
+        return TextPositionSet(positions)
+
+    def from_exact_strings(self, selection: Sequence[str]) -> TextPositionSet:
+        """
+        Construct TextPositionSet from a sequence of strings representing exact quotations.
+
+        First converts the sequence to TextQuoteSelectors, and then to TextPositionSelectors.
+        """
+        selectors = [TextQuoteSelector(exact=item) for item in selection]
+        return self.from_quote_selectors(quotes=selectors)
 
     def from_quote_selectors(
         self, quotes: Sequence[TextQuoteSelector]
     ) -> TextPositionSet:
+        """Construct TextPositionSet from a sequence of TextQuoteSelectors."""
         position_selectors = [quote.as_position(self.passage) for quote in quotes]
         return TextPositionSet(position_selectors)
