@@ -10,7 +10,7 @@ from __future__ import annotations
 import re
 from dataclasses import dataclass
 
-from typing import List, Optional, Sequence, Tuple, Union
+from typing import List, Optional, Tuple, Union
 
 from anchorpoint.textsequences import TextPassage, TextSequence
 from anchorpoint.utils._helper import _is_iterable_non_string
@@ -501,4 +501,3 @@ class TextPositionSet(RangeSet):
                             start=left.real_end, end=right.real_start
                         )
         return self + margin_selectors
-
